# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import evdev

from autopilot.input._uinput import _get_devnode_path

from ubuntu_system_tests.helpers import wait_until

INPUT_DEVICE_NAME = 'autopilot-power-button'

input_device = None


def press_power_button():
    """Simulate a power key press event."""
    global input_device
    input_device = evdev.UInput(name=INPUT_DEVICE_NAME,
                                devnode=_get_devnode_path())
    # wait until the input device is ready
    if not wait_until(_get_input_device, period=0.5):
        raise(RuntimeError('Could not find UInput device.'))
    # Send a press and release event
    input_device.write(evdev.ecodes.EV_KEY, evdev.ecodes.KEY_POWER, 1)
    input_device.write(evdev.ecodes.EV_KEY, evdev.ecodes.KEY_POWER, 0)
    input_device.syn()
    input_device.close()
    input_device = None


def _get_input_device():
    """Find the autopilot input device if it is available and save instace
    in the input_device global variable.
    :return: True if input device found, False otherwise."""
    global input_device
    device = input_device._find_device()
    if device:
        input_device.device = device
    return device
