# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from ubuntu_system_tests.helpers import autopilot
from ubuntu_system_tests.helpers import processes
from ubuntu_system_tests.helpers.scopes.apps import (
    launch_application_from_apps_scope)
from ubuntu_system_tests.helpers import wait_until

APP = 'telegram'
APP_ID = 'com.ubuntu.telegram'
APP_NAME = 'Telegram'
APP_WIN_ID = 'com.ubuntu.telegram_telegram'


def launch_telegram_app():
    """
    Launch the telegram app from apps scope and return proxy object.

    :return: Proxy object for telegram application.

    """
    launch_application_from_apps_scope(APP_NAME)
    if not wait_until(is_telegram_app_running, period=0.5):
        raise RuntimeError('Telegram process did not start.')
    return get_telegram_app_proxy(pid=get_telegram_process_id())


def is_telegram_app_running():
    """ Indicate if the telegram app is currently running """
    return processes.is_process_running(APP)


def get_telegram_app_proxy(pid):
    """
    Return telegram app proxy object from existing process.

    :return: Proxy object for telegram application.
    """
    from ubuntu_system_tests.helpers.telegram._cpo import MainView  # NOQA
    proxy = autopilot.get_proxy_object(pid=pid)
    return autopilot.patched_wait_select_single(
        root=proxy, class_object=MainView, class_name='MainView')


def get_telegram_process_id():
    """
    Return PID of the telegram process to be used for dbus introspection

    Telegram app have two PIDs when its started, the latest process is what
    is usable for dbus introspection, so we return the leftmost PID from the
    list of PIDs.

    :return: PID of telegram app
    """
    return processes.get_process_ids(APP)[0]
