# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import os
import stat

from ubuntu_system_tests.helpers import context
from ubuntu_system_tests.helpers import wait_until
from ubuntu_system_tests.helpers.testbed import write_to_file_with_sudo


def get_unity8_fifo_path():
    """Return path of fake sensor fifo used by unity8 process."""
    return '/tmp/sensor-fifo-{}'.format(context.shared.unity_pid)


def write_to_unity8_fifo(commands):
    """
    Write specified commands to the unity8 sensor fifo buffer.
    :param commands: List of commands to write.
    """
    for command in commands:
        echo_cmd = 'echo "{}"'.format(command)
        write_to_file_with_sudo(get_unity8_fifo_path(), echo_cmd, append=True)


def validate_unity8_fifo_ready():
    """Wait until the unity8 fifo buffer is ready and validate."""
    fifo_path = get_unity8_fifo_path()
    wait_until(lambda: os.path.exists(fifo_path))
    assert(stat.S_ISFIFO(os.stat(fifo_path).st_mode))


def setup_unity8_sensors():
    """Initialize the fake sensors used in the unity8 process."""
    # Delay import to avoid circular dependency
    from ubuntu_system_tests.helpers.sensors import (
        get_fake_sensors_setup_commands)
    cmds = get_fake_sensors_setup_commands()
    write_to_unity8_fifo(cmds)
